@@ -5,7 +5,7 @@
  
 package XML::Compile::Translate::Writer;
 use vars '$VERSION';
-$VERSION = '1.11';
+$VERSION = '1.12';
 
 use base 'XML::Compile::Translate';
 
@@ -349,13 +349,19 @@ sub makeBlockHandler
             my ($doc, $values) = @_;
             my @values = ref $values eq 'ARRAY' ? @$values
                        : defined $values ? $values : ();
-
             @values <= 1
                 or error __x"only one block value for `{tag}', not {count} at {path}"
                      , tag => $multi, count => scalar @values
                      , path => $path, _class => 'misfit';
 
-            @values ? $process->($doc, $values[0]) : undef;
+#           @values ? $process->($doc, $values[0]) : undef;
+            @values or return undef;
+
+            my $starter = keys %$values;
+            my @d = try { $process->($doc, $values[0]) };
+            $@->wasFatal(class => 'misfit') && $starter==keys %$values
+                or $@->reportAll;
+            @d;
         };
         return ($label, bless($code, 'BLOCK'));
     }
